# unitorch.cli.models.bart

## BartProcessor

!!! tip
    **`core/process/bart`** is the section for configuration of BartProcessor.

::: unitorch.cli.models.bart.BartProcessor

## BartForGeneration

!!! tip
    **`core/model/generation/bart`** is the section for configuration of BartForGeneration.

::: unitorch.cli.models.bart.BartForGeneration
